@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Term.pm,v 1.11 2010-11-26 20:32:38 dpchrist Exp $
+# $Id: Term.pm,v 1.12 2010-11-27 03:38:00 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -21,7 +21,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.11 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.12 $ =~ /(\d+)/g);
 
 #######################################################################
 # uses:
@@ -38,7 +38,7 @@ Dpchrist::Term - terminal I/O routines
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.11 $.
+This documentation describes module revision $Revision: 1.12 $.
 
 
 This is alpha test level software
@@ -117,15 +117,32 @@ See 'perldoc Export' for everything in between.
 
 =head1 INSTALLATION
 
-    perl Makefile.PL
-    make
-    make test
-    make install
+Old school:
+
+    $ perl Makefile.PL
+    $ make    
+    $ make test
+    $ make install 
+
+Minimal:
+
+    $ cpan Dpchrist::Debug
+
+Complete:
+
+    $ cpan Bundle::Dpchrist
+
+The following warning may be safely ignored:
+
+    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
+    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
+    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
+    /usr/local/lib/site_perl .) at Makefile.PL line 22.
 
 
-=head1 DEPENDENCIES
+=head2 PREREQUISITES
 
-    Dpchrist::Module
+See Makefile.PL in the source distribution root directory.
 
 
 =head1 SEE ALSO
